import 'package:flutter/widgets.dart';
import 'package:flutter_dynamic_ui/component/base_block.dart';
import 'package:flutter_dynamic_ui/manager/registry.dart';
import 'package:flutter_dynamic_ui/model/data_model.dart';

class BlockManager {
  static BlockManager _instance;

  BlockManager._internal();

  factory BlockManager.getInstance() => _getInstance();

  static _getInstance() {
    if (_instance == null) {
      _instance = BlockManager._internal();
    }
    return _instance;
  }

  Map<String, BaseBlock> blockMap;

  Widget getBlockWidget(BlockData data) {
    final type = data.type;
    if (blockMap.containsKey(type)) {
      return blockMap[type].createWidget(data);
    } else {
      // fallback
      return Container(
        child: Center(
          child: Text("Block No Found"),
        ),
      );
    }
  }

  void addRegistry(BlockRegistry registry) {
    Map<String, BaseBlock> map = registry.getMap();
    blockMap.addAll(map);
  }
}
